@@ -269,7 +269,7 @@ class TRMaid(object):
             self.handle_torrent_section(tor, 'tracker', 'general')
 
     def handle_torrent_section(self, tor, section, subsection):
-        conf = self.conf[section][subsection]
+        conf = self.conf.get(section, {}).get(subsection, {})
         for key in ['download-dir', 'location']:
             if key in conf:
                 correct = normalize_dir(conf.get(key))
@@ -374,8 +374,8 @@ class TRMaid(object):
             if tor is None or tor['downloadDir'] != location:
                 req['location'] = location
 
-        if 'trackers' in conf:
-            req['trackerAdd'] = conf['trackers']
+        if 'trackerAdd' in conf:
+            req['trackerAdd'] = conf['trackerAdd']
 
         return req
 
